# Changes

Version 1.2.0.post1 (2020-12-30)

We closed a total of 11 issues (enhancements and bug fixes) through 4 pull requests, since our last release on 2020-08-07.

## Issues Closed
  - update env variable syntax (#52)
  - Spatial dependence diagnostics returns nan (#47)
  - Random Effects for Spatial Panels (#46)
  - Random Effects Panel (#50)
  - Add GM_Lag_example notebook (#38)
  - Fixed Effects Panel - Spatial Error model (#44)
  - Fixed Effects Panel - Spatial Error (#45)

## Pull Requests
  - update env variable syntax (#52)
  - Random Effects Panel (#50)
  - Fixed Effects Panel (#45)
  - Add GM_Lag_example notebook (#38)

The following individuals contributed to this release:

  - Pedro Amaral
  - Pabloestradac
